@@ -31,9 +31,9 @@ fn exchange_keys<T: AsRef<str>>(client_id: T, session_pubkey: &PublicKey) -> Res
     // exchange public keys
     let cpr_req = ChangePublicKeysRequest::new(client_id.as_ref(), session_pubkey);
     let cpr_resp = cpr_req.send()?;
-    Ok(cpr_resp
+    cpr_resp
         .get_public_key()
-        .ok_or_else(|| anyhow!("Failed to retrieve host public key"))?)
+        .ok_or_else(|| anyhow!("Failed to retrieve host public key"))
 }
 
 fn start_session() -> Result<(String, SecretKey, PublicKey)> {
@@ -72,9 +72,9 @@ fn read_git_request() -> Result<(GitCredentialMessage, String)> {
             }
             format!(
                 "{}://{}/{}",
-                git_req.protocol.clone().unwrap(),
-                git_req.host.clone().unwrap(),
-                git_req.path.clone().unwrap_or_else(|| "".to_owned())
+                git_req.protocol.as_deref().unwrap(),
+                git_req.host.as_deref().unwrap(),
+                git_req.path.as_deref().unwrap_or("")
             )
         }
     };
@@ -89,7 +89,7 @@ fn associated_databases<T: AsRef<str>>(
     let databases: Vec<_> = config
         .get_databases()?
         .iter()
-        .filter(|ref db| {
+        .filter(|db| {
             let mut remain_retries = unlock_options.as_ref().map_or_else(|| 0, |v| v.max_retries);
             let mut success = false;
             loop {
@@ -107,11 +107,7 @@ fn associated_databases<T: AsRef<str>>(
                     }
                 };
                 if let Ok(ref taso_resp) = taso_resp {
-                    success = taso_resp
-                        .success
-                        .clone()
-                        .unwrap_or_else(|| KeePassBoolean(false))
-                        .into();
+                    success = taso_resp.success.as_ref().map_or(false, |s| *s.as_ref());
                 }
                 if taso_resp.is_err() || !success {
                     warn!(
@@ -417,11 +413,10 @@ fn verify_caller(config: &Config) -> Result<Option<CurrentCaller>> {
     }
     let current_caller = CurrentCaller::new()?;
     let callers = config.get_callers()?;
-    let matching_callers: Vec<_> = callers
+    let matching_callers = callers
         .iter()
-        .filter(|caller| current_caller.matches(caller))
-        .collect();
-    if matching_callers.is_empty() {
+        .filter(|caller| current_caller.matches(caller));
+    if matching_callers.count() == 0 {
         if config.count_callers() == 0 && cfg!(feature = "strict-caller") {
             warn!("No caller profiles defined. You must configure callers before databases when strict-caller feature is enabled");
         }
@@ -468,8 +463,11 @@ fn get_totp_for<T: AsRef<str>>(client_id: T, uuid: T) -> Result<String> {
     }
 }
 
-fn filter_kph_logins(login_entries: &[LoginEntry]) -> (u32, Vec<&LoginEntry>) {
+fn filter_kph_logins(login_entries: &[LoginEntry], skip: bool) -> (u32, Vec<&LoginEntry>) {
     let mut kph_false = 0u32;
+    if skip {
+        return (kph_false, login_entries.iter().collect());
+    }
     let login_entries: Vec<&LoginEntry> = login_entries
         .iter()
         .filter(|entry| {
@@ -497,6 +495,7 @@ fn get_logins<T: AsRef<Path>>(
     config_path: T,
     unlock_options: &Option<UnlockOptions>,
     get_mode: &Option<GetMode>,
+    no_filter: bool,
     advanced_fields: bool,
     json: bool,
 ) -> Result<()> {
@@ -534,7 +533,7 @@ fn get_logins<T: AsRef<Path>>(
 
     let login_entries = get_logins_for(&config, &client_id, &url, unlock_options)?;
     info!("KeePassXC returned {} login(s)", login_entries.len());
-    let (kph_false, mut login_entries) = filter_kph_logins(&login_entries);
+    let (kph_false, mut login_entries) = filter_kph_logins(&login_entries, no_filter);
     if kph_false > 0 {
         info!("{} login(s) were labelled as KPH: git == false", kph_false);
     }
@@ -564,21 +563,20 @@ fn get_logins<T: AsRef<Path>>(
     let mut git_resp = git_req;
 
     // entry found handle TOTP now
-    match get_mode {
-        Some(mode) => match mode {
+    if let Some(mode) = get_mode {
+        match mode {
             GetMode::PasswordAndTotp => {
-                if let Ok(totp) = get_totp_for(client_id, login.uuid.clone()) {
+                if let Ok(totp) = get_totp_for(&client_id, &login.uuid) {
                     git_resp.totp = Some(totp);
                 } else {
                     error!("Failed to get TOTP");
                 }
             }
             GetMode::TotpOnly => {
-                git_resp.totp = Some(get_totp_for(client_id, login.uuid.clone())?);
+                git_resp.totp = Some(get_totp_for(&client_id, &login.uuid)?);
             }
             _ => {}
-        },
-        _ => {}
+        }
     }
 
     if get_mode.is_none() || get_mode.as_ref().unwrap() != &GetMode::TotpOnly {
@@ -606,6 +604,7 @@ fn get_logins<T: AsRef<Path>>(
 fn store_login<T: AsRef<Path>>(
     config_path: T,
     unlock_options: &Option<UnlockOptions>,
+    no_filter: bool,
 ) -> Result<()> {
     let config = Config::read_from(config_path.as_ref())?;
     verify_caller(&config)?;
@@ -623,7 +622,7 @@ fn store_login<T: AsRef<Path>>(
 
     let login_entries =
         get_logins_for(&config, &client_id, &url, unlock_options).and_then(|entries| {
-            let (kph_false, entries) = filter_kph_logins(&entries);
+            let (kph_false, entries) = filter_kph_logins(&entries, no_filter);
             if kph_false > 0 {
                 info!("{} login(s) were labelled as KPH: git == false", kph_false);
             }
@@ -731,7 +730,7 @@ fn lock_database<T: AsRef<Path>>(config_path: T) -> Result<()> {
 }
 
 fn edit<T: AsRef<Path>>(config_path: T) -> Result<()> {
-    const KNOWN_EDITORS: &'static [&'static str] = &["nvim", "vim", "kak", "vi", "nano", "ex"];
+    const KNOWN_EDITORS: &[&str] = &["nvim", "vim", "kak", "vi", "nano", "ex"];
     let find_editor = || -> Option<String> {
         if let Ok(editor) = env::var("VISUAL") {
             debug!("Found editor {} via VISUAL environment variable", editor);
@@ -862,6 +861,13 @@ fn real_main() -> Result<()> {
         "totp" => Some(GetMode::TotpOnly),
         _ => None,
     };
+    let no_filter = match subcommand {
+        "get" | "store" => args
+            .subcommand_matches(subcommand)
+            .map(|m| m.is_present("no-filter"))
+            .unwrap(),
+        _ => false,
+    };
     let advanced_fields = match subcommand {
         "get" => args
             .subcommand_matches("get")
@@ -886,10 +892,11 @@ fn real_main() -> Result<()> {
             config_path,
             &unlock_options,
             &get_mode,
+            no_filter,
             advanced_fields,
             json,
         ),
-        "store" => store_login(config_path, &unlock_options),
+        "store" => store_login(config_path, &unlock_options, no_filter),
         "erase" => erase_login(),
         "lock" => lock_database(config_path),
         _ => Err(anyhow!(anyhow!("Unrecognised subcommand"))),
