@@ -12,6 +12,7 @@ use mockall::mock;
 use named_pipe::PipeClient;
 use once_cell::unsync::OnceCell;
 use std::cell::RefCell;
+use std::env;
 use std::fmt;
 use std::io::{Read, Write};
 #[cfg(unix)]
@@ -24,6 +25,7 @@ use std::str;
 const NAMED_PIPE_CONNECT_TIMEOUT_MS: u32 = 100;
 const KEEPASS_SOCKET_NAME: &str = "org.keepassxc.KeePassXC.BrowserServer";
 const KEEPASS_SOCKET_NAME_LEGACY: &str = "kpxc_server";
+const KEEPASS_SOCKET_ENVIRONMENT_VARIABLE: &str = "KEEPASSXC_BROWSER_SOCKET_PATH";
 
 #[macro_export]
 macro_rules! error {
@@ -58,6 +60,9 @@ thread_local!(pub static SOCKET_PATH: OnceCell<PathBuf> = OnceCell::new());
 pub fn get_socket_path() -> Result<PathBuf> {
     let socket_path = SOCKET_PATH.with(|s| -> Result<_> {
         Ok(s.get_or_try_init(|| -> Result<_> {
+            if let Ok(env_socket_path) = env::var(KEEPASS_SOCKET_ENVIRONMENT_VARIABLE) {
+                return Ok(PathBuf::from(env_socket_path));
+            }
             let base_dirs = directories_next::BaseDirs::new()
                 .ok_or_else(|| anyhow!("Failed to initialise base_dirs"))?;
             let get_socket_path_with_name = |name: &str| -> Result<PathBuf> {
@@ -146,7 +151,7 @@ impl std::error::Error for CryptionError {}
 #[cfg(unix)]
 fn get_stream() -> Result<Rc<RefCell<UnixStream>>> {
     thread_local!(static STREAM: OnceCell<Rc<RefCell<UnixStream>>> = OnceCell::new());
-    Ok(STREAM.with(|s| -> Result<_> {
+    STREAM.with(|s| -> Result<_> {
         Ok(s.get_or_try_init(|| -> Result<_> {
             let path = get_socket_path()?;
             Ok(Rc::new(RefCell::new(
@@ -159,13 +164,13 @@ fn get_stream() -> Result<Rc<RefCell<UnixStream>>> {
             )))
         })?
         .clone())
-    })?)
+    })
 }
 
 #[cfg(windows)]
 fn get_stream() -> Result<Rc<RefCell<PipeClient>>> {
     thread_local!(static STREAM: OnceCell<Rc<RefCell<PipeClient>>> = OnceCell::new());
-    Ok(STREAM.with(|s| -> Result<_> {
+    STREAM.with(|s| -> Result<_> {
         Ok(s.get_or_try_init(|| -> Result<_> {
             let path = get_socket_path()?;
             Ok(Rc::new(RefCell::new(
@@ -175,7 +180,7 @@ fn get_stream() -> Result<Rc<RefCell<PipeClient>>> {
             )))
         })?
         .clone())
-    })?)
+    })
 }
 
 pub trait MessagingUtilsTrait {
@@ -341,7 +346,7 @@ pub fn get_client_box(
     client_secret_key: Option<&SecretKey>,
 ) -> Result<Rc<SalsaBox>> {
     thread_local!(static CLIENT_BOX: OnceCell<Rc<SalsaBox>> = OnceCell::new());
-    Ok(CLIENT_BOX.with(|cb| -> Result<_> {
+    CLIENT_BOX.with(|cb| -> Result<_> {
         Ok(cb.get_or_try_init(|| -> Result<_> {
             let client_secret_key = client_secret_key.ok_or_else(||
                 anyhow!("get_client_box() is called before client secret key is available, this shouldn't happen")
@@ -351,7 +356,7 @@ pub fn get_client_box(
             )?;
             Ok(Rc::new(SalsaBox::new(host_public_key, client_secret_key)))
         })?.clone())
-    })?)
+    })
 }
 
 type NaClNonce = generic_array::GenericArray<u8, generic_array::typenum::U24>;
@@ -368,7 +373,7 @@ pub fn to_encrypted_json<M: serde::Serialize>(request: &M, nonce: &NaClNonce) ->
     debug!("ENC : {}", json);
     let client_box = get_client_box(None, None)?;
     let encrypted = client_box
-        .encrypt(&nonce, json.as_bytes())
+        .encrypt(nonce, json.as_bytes())
         .map_err(|_| CryptionError(true))?;
     let encrypted = base64::encode(&encrypted);
     Ok(encrypted)
